The Structure of a Wordnet
==========================

Words, Senses, and Synsets
--------------------------

Synset Relations
----------------

Sense Relations
---------------

Sense-Sense

Sense-Synset

Other Information
-----------------

Definitions, Examples, Metadata
